@@ -18,9 +18,9 @@
  * Forward declarations
  */
 
-static struct sieve_ast_node *sieve_ast_node_create
-	(struct sieve_ast *ast, struct sieve_ast_node *parent,
-		enum sieve_ast_type type, unsigned int source_line);
+static struct sieve_ast_node *
+sieve_ast_node_create(struct sieve_ast *ast, struct sieve_ast_node *parent,
+		      enum sieve_ast_type type, unsigned int source_line);
 
 /*
  * Types
@@ -54,8 +54,7 @@ struct sieve_ast {
 	ARRAY(struct sieve_ast_extension_reg) extensions;
 };
 
-struct sieve_ast *sieve_ast_create
-(struct sieve_script *script)
+struct sieve_ast *sieve_ast_create(struct sieve_script *script)
 {
 	pool_t pool;
 	struct sieve_ast *ast;
@@ -100,10 +99,10 @@ void sieve_ast_unref(struct sieve_ast **ast)
 
 	/* Signal registered extensions that the AST is being destroyed */
 	extrs = array_get(&(*ast)->extensions, &ext_count);
-	for ( i = 0; i < ext_count; i++ ) {
-		if ( extrs[i].ast_ext != NULL &&
-			extrs[i].ast_ext->free != NULL )
-			extrs[i].ast_ext->free(extrs[i].ext, *ast, extrs[i].context);
+	for (i = 0; i < ext_count; i++) {
+		if (extrs[i].ast_ext != NULL &&	extrs[i].ast_ext->free != NULL)
+			extrs[i].ast_ext->free(extrs[i].ext, *ast,
+					       extrs[i].context);
 	}
 
 	/* Destroy AST */
@@ -131,27 +130,26 @@ struct sieve_script *sieve_ast_script(struct sieve_ast *ast)
  * Extension support
  */
 
-void sieve_ast_extension_link
-(struct sieve_ast *ast, const struct sieve_extension *ext,
-	bool required)
+void sieve_ast_extension_link(struct sieve_ast *ast,
+			      const struct sieve_extension *ext, bool required)
 {
 	unsigned int i, ext_count;
 	const struct sieve_extension *const *extensions;
 	struct sieve_ast_extension_reg *reg;
 
-	if ( ext->id < 0 ) return;
+	if (ext->id < 0)
+		return;
 
 	/* Initialize registration */
-	reg = array_idx_get_space(&ast->extensions,
-		(unsigned int) ext->id);
+	reg = array_idx_get_space(&ast->extensions, (unsigned int)ext->id);
 	i_assert(reg->ext == NULL || reg->ext == ext);
 	reg->ext = ext;
 	reg->required = reg->required || required;
 
 	/* Prevent duplicates */
 	extensions = array_get(&ast->linked_extensions, &ext_count);
-	for ( i = 0; i < ext_count; i++ ) {
-		if ( extensions[i] == ext )
+	for (i = 0; i < ext_count; i++) {
+		if (extensions[i] == ext)
 			return;
 	}
 
@@ -159,48 +157,52 @@ void sieve_ast_extension_link
 	array_append(&ast->linked_extensions, &ext, 1);
 }
 
-const struct sieve_extension * const *sieve_ast_extensions_get
-(struct sieve_ast *ast, unsigned int *count_r)
+const struct sieve_extension * const *
+sieve_ast_extensions_get(struct sieve_ast *ast, unsigned int *count_r)
 {
 	return array_get(&ast->linked_extensions, count_r);
 }
 
-void sieve_ast_extension_register
-(struct sieve_ast *ast, const struct sieve_extension *ext,
-	const struct sieve_ast_extension *ast_ext, void *context)
+void sieve_ast_extension_register(struct sieve_ast *ast,
+				  const struct sieve_extension *ext,
+				  const struct sieve_ast_extension *ast_ext,
+				  void *context)
 {
 	struct sieve_ast_extension_reg *reg;
 
-	if ( ext->id < 0 ) return;
+	if (ext->id < 0)
+		return;
 
 	/* Initialize registration */
-	reg = array_idx_get_space(&ast->extensions, (unsigned int) ext->id);
+	reg = array_idx_get_space(&ast->extensions, (unsigned int)ext->id);
 	i_assert(reg->ext == NULL || reg->ext == ext);
 	reg->ext = ext;
 	reg->ast_ext = ast_ext;
 	reg->context = context;
 }
 
-void sieve_ast_extension_set_context
-(struct sieve_ast *ast, const struct sieve_extension *ext, void *context)
+void sieve_ast_extension_set_context(struct sieve_ast *ast,
+				     const struct sieve_extension *ext,
+				     void *context)
 {
 	struct sieve_ast_extension_reg *reg;
 
-	if ( ext->id < 0 ) return;
+	if (ext->id < 0)
+		return;
 
-	reg = array_idx_get_space(&ast->extensions, (unsigned int) ext->id);
+	reg = array_idx_get_space(&ast->extensions, (unsigned int)ext->id);
 	reg->context = context;
 }
 
-void *sieve_ast_extension_get_context
-(struct sieve_ast *ast, const struct sieve_extension *ext)
+void *sieve_ast_extension_get_context(struct sieve_ast *ast,
+				      const struct sieve_extension *ext)
 {
 	const struct sieve_ast_extension_reg *reg;
 
-	if  ( ext->id < 0 || ext->id >= (int) array_count(&ast->extensions) )
+	if  (ext->id < 0 || ext->id >= (int)array_count(&ast->extensions))
 		return NULL;
 
-	reg = array_idx(&ast->extensions, (unsigned int) ext->id);
+	reg = array_idx(&ast->extensions, (unsigned int)ext->id);
 
 	return reg->context;
 }
@@ -210,8 +212,8 @@ bool sieve_ast_extension_is_required
 {
 	const struct sieve_ast_extension_reg *reg;
 
-	i_assert( ext->id >= 0 &&
-		ext->id < (int) array_count(&ast->extensions) );
+	i_assert(ext->id >= 0 &&
+		 ext->id < (int)array_count(&ast->extensions));
 
 	reg = array_idx(&ast->extensions, (unsigned int)ext->id);
 	return reg->required;
@@ -222,22 +224,22 @@ bool sieve_ast_extension_is_required
  */
 
 /* Very simplistic linked list implementation
- * FIXME: Move to separate file
+   FIXME: Merge with core
  */
 #define __LIST_CREATE(pool, type) { \
 		type *list = p_new(pool, type, 1); \
 		list->head = NULL; \
 		list->tail = NULL; \
-		list->len = 0;		\
+		list->len = 0; \
 		return list; \
 	}
 
 #define __LIST_ADD(list, node) { \
-		if ( list->len + 1 < list->len ) \
+		if (list->len + 1 < list->len) \
 			return FALSE; \
 		\
 		node->next = NULL; \
-		if ( list->head == NULL ) { \
+		if (list->head == NULL) { \
 			node->prev = NULL; \
 			list->head = node; \
 			list->tail = node; \
@@ -252,11 +254,11 @@ bool sieve_ast_extension_is_required
 	}
 
 #define __LIST_INSERT(list, before, node) { \
-		if ( list->len + 1 < list->len ) \
+		if (list->len + 1 < list->len) \
 			return FALSE; \
 		\
 		node->next = before; \
-		if ( list->head == before ) { \
+		if (list->head == before) { \
 			node->prev = NULL; \
 			list->head = node; \
 		} else { \
@@ -273,12 +275,13 @@ bool sieve_ast_extension_is_required
 #define __LIST_JOIN(list, node_type, items) { \
 		node_type *node; \
 		\
-		if ( list->len + items->len < list->len ) \
+		if (list->len + items->len < list->len) \
 			return FALSE; \
 		\
-		if ( items->len == 0 ) return TRUE; \
+		if (items->len == 0) \
+			return TRUE; \
 		\
-		if ( list->head == NULL ) { \
+		if (list->head == NULL) { \
 			list->head = items->head; \
 			list->tail = items->tail; \
 		} else { \
@@ -289,7 +292,7 @@ bool sieve_ast_extension_is_required
 		list->len += items->len; \
 		\
 		node = items->head; \
-		while ( node != NULL ) { \
+		while (node != NULL) { \
 			node->list = list; \
 			node = node->next; \
 		} \
@@ -304,19 +307,19 @@ bool sieve_ast_extension_is_required
 		\
 		left = count - 1; \
 		last = first; \
-		while ( left > 0 && last->next != NULL ) { \
+		while (left > 0 && last->next != NULL) { \
 			left--; \
 			last = last->next; \
 		} \
 		\
-		if ( first->list->head == first ) \
+		if (first->list->head == first) \
 			first->list->head = last->next; \
-		if ( first->list->tail == last ) \
+		if (first->list->tail == last) \
 			first->list->tail = first->prev; \
 		\
-		if ( first->prev != NULL ) \
+		if (first->prev != NULL) \
 			first->prev->next = last->next;	\
-		if ( last->next != NULL ) \
+		if (last->next != NULL) \
 			last->next->prev = first->prev; \
 		\
 		first->list->len -= count - left; \
@@ -330,15 +333,16 @@ bool sieve_ast_extension_is_required
 
 /* List of AST nodes */
 
-static struct sieve_ast_list *sieve_ast_list_create(pool_t pool)
+static struct sieve_ast_list *
+sieve_ast_list_create(pool_t pool)
 	__LIST_CREATE(pool, struct sieve_ast_list)
 
-static bool sieve_ast_list_add
-(struct sieve_ast_list *list, struct sieve_ast_node *node)
+static bool
+sieve_ast_list_add(struct sieve_ast_list *list, struct sieve_ast_node *node)
 	__LIST_ADD(list, node)
 
-static struct sieve_ast_node *sieve_ast_list_detach
-(struct sieve_ast_node *first, unsigned int count)
+static struct sieve_ast_node *
+sieve_ast_list_detach(struct sieve_ast_node *first, unsigned int count)
 	__LIST_DETACH(first, struct sieve_ast_node, count)
 
 /* List of argument AST nodes */
@@ -346,35 +350,37 @@ static struct sieve_ast_node *sieve_ast_list_detach
 struct sieve_ast_arg_list *sieve_ast_arg_list_create(pool_t pool)
 	__LIST_CREATE(pool, struct sieve_ast_arg_list)
 
-bool sieve_ast_arg_list_add
-(struct sieve_ast_arg_list *list, struct sieve_ast_argument *argument)
+bool sieve_ast_arg_list_add(struct sieve_ast_arg_list *list,
+			    struct sieve_ast_argument *argument)
 	__LIST_ADD(list, argument)
 
-bool sieve_ast_arg_list_insert
-(struct sieve_ast_arg_list *list, struct sieve_ast_argument *before,
-	struct sieve_ast_argument *argument)
+bool sieve_ast_arg_list_insert(struct sieve_ast_arg_list *list,
+			       struct sieve_ast_argument *before,
+			       struct sieve_ast_argument *argument)
 	__LIST_INSERT(list, before, argument)
 
-static bool sieve_ast_arg_list_join
-(struct sieve_ast_arg_list *list, struct sieve_ast_arg_list *items)
+static bool
+sieve_ast_arg_list_join(struct sieve_ast_arg_list *list,
+			struct sieve_ast_arg_list *items)
 	__LIST_JOIN(list, struct sieve_ast_argument, items)
 
-static struct sieve_ast_argument *sieve_ast_arg_list_detach
-(struct sieve_ast_argument *first, const unsigned int count)
+static struct sieve_ast_argument *
+sieve_ast_arg_list_detach(struct sieve_ast_argument *first,
+			  const unsigned int count)
 	__LIST_DETACH(first, struct sieve_ast_argument, count)
 
-void sieve_ast_arg_list_substitute
-(struct sieve_ast_arg_list *list, struct sieve_ast_argument *argument,
-	struct sieve_ast_argument *replacement)
+void sieve_ast_arg_list_substitute(struct sieve_ast_arg_list *list,
+				   struct sieve_ast_argument *argument,
+				   struct sieve_ast_argument *replacement)
 {
-	if ( list->head == argument )
+	if (list->head == argument)
 		list->head = replacement;
-	if ( list->tail == argument )
+	if (list->tail == argument)
 		list->tail = replacement;
 
-	if ( argument->prev != NULL )
+	if (argument->prev != NULL)
 		argument->prev->next = replacement;
-	if ( argument->next != NULL )
+	if (argument->next != NULL)
 		argument->next->prev = replacement;
 
 	replacement->prev = argument->prev;
@@ -389,11 +395,12 @@ void sieve_ast_arg_list_substitute
  * AST node
  */
 
-static struct sieve_ast_node *sieve_ast_node_create
-(struct sieve_ast *ast, struct sieve_ast_node *parent, enum sieve_ast_type type,
-	unsigned int source_line)
+static struct sieve_ast_node *
+sieve_ast_node_create(struct sieve_ast *ast, struct sieve_ast_node *parent,
+		      enum sieve_ast_type type, unsigned int source_line)
 {
-	struct sieve_ast_node *node = p_new(ast->pool, struct sieve_ast_node, 1);
+	struct sieve_ast_node *node =
+		p_new(ast->pool, struct sieve_ast_node, 1);
 
 	node->ast = ast;
 	node->parent = parent;
@@ -414,11 +421,12 @@ static struct sieve_ast_node *sieve_ast_node_create
 	return node;
 }
 
-static bool sieve_ast_node_add_command
-(struct sieve_ast_node *node, struct sieve_ast_node *command)
+static bool
+sieve_ast_node_add_command(struct sieve_ast_node *node,
+			   struct sieve_ast_node *command)
 {
-	i_assert( command->type == SAT_COMMAND &&
-		(node->type == SAT_ROOT || node->type == SAT_COMMAND) );
+	i_assert(command->type == SAT_COMMAND &&
+		 (node->type == SAT_ROOT || node->type == SAT_COMMAND));
 
 	if (node->commands == NULL)
 		node->commands = sieve_ast_list_create(node->ast->pool);
@@ -426,11 +434,12 @@ static bool sieve_ast_node_add_command
 	return sieve_ast_list_add(node->commands, command);
 }
 
-static bool sieve_ast_node_add_test
-(struct sieve_ast_node *node, struct sieve_ast_node *test)
+static bool
+sieve_ast_node_add_test(struct sieve_ast_node *node,
+			struct sieve_ast_node *test)
 {
-	i_assert( test->type == SAT_TEST &&
-		(node->type == SAT_TEST || node->type == SAT_COMMAND) );
+	i_assert(test->type == SAT_TEST &&
+		 (node->type == SAT_TEST || node->type == SAT_COMMAND));
 
 	if (node->tests == NULL)
 		node->tests = sieve_ast_list_create(node->ast->pool);
@@ -438,10 +447,11 @@ static bool sieve_ast_node_add_test
 	return sieve_ast_list_add(node->tests, test);
 }
 
-static bool sieve_ast_node_add_argument
-(struct sieve_ast_node *node, struct sieve_ast_argument *argument)
+static bool
+sieve_ast_node_add_argument(struct sieve_ast_node *node,
+			    struct sieve_ast_argument *argument)
 {
-	i_assert( node->type == SAT_TEST || node->type == SAT_COMMAND );
+	i_assert(node->type == SAT_TEST || node->type == SAT_COMMAND);
 
 	if (node->arguments == NULL)
 		node->arguments = sieve_ast_arg_list_create(node->ast->pool);
@@ -449,23 +459,24 @@ static bool sieve_ast_node_add_argument
 	return sieve_ast_arg_list_add(node->arguments, argument);
 }
 
-struct sieve_ast_node *sieve_ast_node_detach
-(struct sieve_ast_node *first)
+struct sieve_ast_node *sieve_ast_node_detach(struct sieve_ast_node *first)
 {
 	return sieve_ast_list_detach(first, 1);
 }
 
-const char *sieve_ast_type_name
-(enum sieve_ast_type ast_type)
+const char *sieve_ast_type_name(enum sieve_ast_type ast_type)
 {
-	switch ( ast_type ) {
-
-	case SAT_NONE: return "none";
-	case SAT_ROOT: return "ast root node";
-	case SAT_COMMAND: return "command";
-	case SAT_TEST: return "test";
-
-	default: return "??AST NODE??";
+	switch (ast_type) {
+	case SAT_NONE:
+		return "none";
+	case SAT_ROOT:
+		return "ast root node";
+	case SAT_COMMAND:
+		return "command";
+	case SAT_TEST:
+		return "test";
+	default:
+		return "??AST NODE??";
 	}
 }
 
@@ -473,8 +484,8 @@ const char *sieve_ast_type_name
  * Argument AST node
  */
 
-struct sieve_ast_argument *sieve_ast_argument_create
-(struct sieve_ast *ast, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_create(struct sieve_ast *ast, unsigned int source_line)
 {
 	struct sieve_ast_argument *arg =
 		p_new(ast->pool, struct sieve_ast_argument, 1);
@@ -491,17 +502,19 @@ struct sieve_ast_argument *sieve_ast_argument_create
 	return arg;
 }
 
-static void sieve_ast_argument_substitute
-(struct sieve_ast_argument *argument, struct sieve_ast_argument *replacement)
+static void
+sieve_ast_argument_substitute(struct sieve_ast_argument *argument,
+			      struct sieve_ast_argument *replacement)
 {
 	sieve_ast_arg_list_substitute(argument->list, argument, replacement);
 }
 
-struct sieve_ast_argument *sieve_ast_argument_string_create_raw
-(struct sieve_ast *ast, string_t *str, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_string_create_raw(struct sieve_ast *ast, string_t *str,
+				     unsigned int source_line)
 {
-	struct sieve_ast_argument *argument = sieve_ast_argument_create
-		(ast, source_line);
+	struct sieve_ast_argument *argument =
+		sieve_ast_argument_create(ast, source_line);
 
 	argument->type = SAAT_STRING;
 	argument->_value.str = str;
@@ -509,8 +522,9 @@ struct sieve_ast_argument *sieve_ast_argument_string_create_raw
 	return argument;
 }
 
-struct sieve_ast_argument *sieve_ast_argument_string_create
-(struct sieve_ast_node *node, const string_t *str, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_string_create(struct sieve_ast_node *node,
+				 const string_t *str, unsigned int source_line)
 {
 	struct sieve_ast_argument *argument;
 	string_t *newstr;
@@ -522,8 +536,8 @@ struct sieve_ast_argument *sieve_ast_argument_string_create
 	str_append_str(newstr, str);
 
 	/* Create string argument */
-	argument = sieve_ast_argument_string_create_raw
-		(node->ast, newstr, source_line);
+	argument = sieve_ast_argument_string_create_raw(
+		node->ast, newstr, source_line);
 
 	/* Add argument to command/test node */
 	sieve_ast_node_add_argument(node, argument);
@@ -531,8 +545,9 @@ struct sieve_ast_argument *sieve_ast_argument_string_create
 	return argument;
 }
 
-struct sieve_ast_argument *sieve_ast_argument_cstring_create
-(struct sieve_ast_node *node, const char *str, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_cstring_create(struct sieve_ast_node *node, const char *str,
+				  unsigned int source_line)
 {
 	struct sieve_ast_argument *argument;
 	string_t *newstr;
@@ -544,8 +559,8 @@ struct sieve_ast_argument *sieve_ast_argument_cstring_create
 	str_append(newstr, str);
 
 	/* Create string argument */
-	argument = sieve_ast_argument_string_create_raw
-		(node->ast, newstr, source_line);
+	argument = sieve_ast_argument_string_create_raw(
+		node->ast, newstr, source_line);
 
 	/* Add argument to command/test node */
 	sieve_ast_node_add_argument(node, argument);
@@ -553,31 +568,32 @@ struct sieve_ast_argument *sieve_ast_argument_cstring_create
 	return argument;
 }
 
-void sieve_ast_argument_string_set
-(struct sieve_ast_argument *argument, string_t *newstr)
+void sieve_ast_argument_string_set(struct sieve_ast_argument *argument,
+				   string_t *newstr)
 {
-	i_assert( argument->type == SAAT_STRING);
+	i_assert(argument->type == SAAT_STRING);
 	argument->_value.str = newstr;
 }
 
-void sieve_ast_argument_string_setc
-(struct sieve_ast_argument *argument, const char *newstr)
+void sieve_ast_argument_string_setc(struct sieve_ast_argument *argument,
+				    const char *newstr)
 {
-	i_assert( argument->type == SAAT_STRING);
+	i_assert(argument->type == SAAT_STRING);
 
 	str_truncate(argument->_value.str, 0);
 	str_append(argument->_value.str, newstr);
 }
 
-void sieve_ast_argument_number_substitute
-(struct sieve_ast_argument *argument, unsigned int number)
+void sieve_ast_argument_number_substitute(struct sieve_ast_argument *argument,
+					  sieve_number_t number)
 {
 	argument->type = SAAT_NUMBER;
 	argument->_value.number = number;
 }
 
-struct sieve_ast_argument *sieve_ast_argument_stringlist_create
-(struct sieve_ast_node *node, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_stringlist_create(struct sieve_ast_node *node,
+				     unsigned int source_line)
 {
 	struct sieve_ast_argument *argument =
 		sieve_ast_argument_create(node->ast, source_line);
@@ -590,8 +606,9 @@ struct sieve_ast_argument *sieve_ast_argument_stringlist_create
 	return argument;
 }
 
-struct sieve_ast_argument *sieve_ast_argument_stringlist_substitute
-(struct sieve_ast_node *node, struct sieve_ast_argument *arg)
+struct sieve_ast_argument *
+sieve_ast_argument_stringlist_substitute(struct sieve_ast_node *node,
+					 struct sieve_ast_argument *arg)
 {
 	struct sieve_ast_argument *argument =
 		sieve_ast_argument_create(node->ast, arg->source_line);
@@ -604,31 +621,39 @@ struct sieve_ast_argument *sieve_ast_argument_stringlist_substitute
 	return argument;
 }
 
-static inline bool _sieve_ast_stringlist_add_item
-(struct sieve_ast_argument *list, struct sieve_ast_argument *item)
+static inline bool
+_sieve_ast_stringlist_add_item(struct sieve_ast_argument *list,
+			       struct sieve_ast_argument *item)
 {
-	i_assert( list->type == SAAT_STRING_LIST );
+	i_assert(list->type == SAAT_STRING_LIST);
 
-	if ( list->_value.strlist == NULL )
-		list->_value.strlist = sieve_ast_arg_list_create(list->ast->pool);
+	if (list->_value.strlist == NULL) {
+		list->_value.strlist =
+			sieve_ast_arg_list_create(list->ast->pool);
+	}
 
 	return sieve_ast_arg_list_add(list->_value.strlist, item);
 }
 
-static bool sieve_ast_stringlist_add_stringlist
-(struct sieve_ast_argument *list, struct sieve_ast_argument *items)
+static bool
+sieve_ast_stringlist_add_stringlist(struct sieve_ast_argument *list,
+				    struct sieve_ast_argument *items)
 {
-	i_assert( list->type == SAAT_STRING_LIST );
-	i_assert( items->type == SAAT_STRING_LIST );
+	i_assert(list->type == SAAT_STRING_LIST);
+	i_assert(items->type == SAAT_STRING_LIST);
 
-	if ( list->_value.strlist == NULL )
-		list->_value.strlist = sieve_ast_arg_list_create(list->ast->pool);
+	if (list->_value.strlist == NULL) {
+		list->_value.strlist =
+			sieve_ast_arg_list_create(list->ast->pool);
+	}
 
-	return sieve_ast_arg_list_join(list->_value.strlist, items->_value.strlist);
+	return sieve_ast_arg_list_join(list->_value.strlist,
+				       items->_value.strlist);
 }
 
-static bool _sieve_ast_stringlist_add_str
-(struct sieve_ast_argument *list, string_t *str, unsigned int source_line)
+static bool
+_sieve_ast_stringlist_add_str(struct sieve_ast_argument *list, string_t *str,
+			      unsigned int source_line)
 {
 	struct sieve_ast_argument *stritem;
 
@@ -639,8 +664,8 @@ static bool _sieve_ast_stringlist_add_str
 	return _sieve_ast_stringlist_add_item(list, stritem);
 }
 
-bool sieve_ast_stringlist_add
-(struct sieve_ast_argument *list, const string_t *str, unsigned int source_line)
+bool sieve_ast_stringlist_add(struct sieve_ast_argument *list,
+			      const string_t *str, unsigned int source_line)
 {
 	string_t *copied_str = str_new(list->ast->pool, str_len(str));
 	str_append_str(copied_str, str);
@@ -648,8 +673,8 @@ bool sieve_ast_stringlist_add
 	return _sieve_ast_stringlist_add_str(list, copied_str, source_line);
 }
 
-bool sieve_ast_stringlist_add_strc
-(struct sieve_ast_argument *list, const char *str, unsigned int source_line)
+bool sieve_ast_stringlist_add_strc(struct sieve_ast_argument *list,
+				   const char *str, unsigned int source_line)
 {
 	string_t *copied_str = str_new(list->ast->pool, strlen(str));
 	str_append(copied_str, str);
@@ -657,8 +682,9 @@ bool sieve_ast_stringlist_add_strc
 	return _sieve_ast_stringlist_add_str(list, copied_str, source_line);
 }
 
-struct sieve_ast_argument *sieve_ast_argument_tag_create
-(struct sieve_ast_node *node, const char *tag, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_tag_create(struct sieve_ast_node *node, const char *tag,
+			      unsigned int source_line)
 {
 	struct sieve_ast_argument *argument =
 		sieve_ast_argument_create(node->ast, source_line);
@@ -666,14 +692,14 @@ struct sieve_ast_argument *sieve_ast_argument_tag_create
 	argument->type = SAAT_TAG;
 	argument->_value.tag = p_strdup(node->ast->pool, tag);
 
-	if ( !sieve_ast_node_add_argument(node, argument) )
+	if (!sieve_ast_node_add_argument(node, argument))
 		return NULL;
-
 	return argument;
 }
 
-struct sieve_ast_argument *sieve_ast_argument_tag_insert
-(struct sieve_ast_argument *before, const char *tag, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_tag_insert(struct sieve_ast_argument *before,
+			      const char *tag, unsigned int source_line)
 {
 	struct sieve_ast_argument *argument =
 		sieve_ast_argument_create(before->ast, source_line);
@@ -681,95 +707,94 @@ struct sieve_ast_argument *sieve_ast_argument_tag_insert
 	argument->type = SAAT_TAG;
 	argument->_value.tag = p_strdup(before->ast->pool, tag);
 
-	if ( !sieve_ast_arg_list_insert(before->list, before, argument) )
+	if (!sieve_ast_arg_list_insert(before->list, before, argument))
 		return NULL;
-
 	return argument;
 }
 
-struct sieve_ast_argument *sieve_ast_argument_number_create
-(struct sieve_ast_node *node, unsigned int number, unsigned int source_line)
+struct sieve_ast_argument *
+sieve_ast_argument_number_create(struct sieve_ast_node *node,
+				 sieve_number_t number,
+				 unsigned int source_line)
 {
-
 	struct sieve_ast_argument *argument =
 		sieve_ast_argument_create(node->ast, source_line);
 
 	argument->type = SAAT_NUMBER;
 	argument->_value.number = number;
 
-	if ( !sieve_ast_node_add_argument(node, argument) )
+	if (!sieve_ast_node_add_argument(node, argument))
 		return NULL;
-
 	return argument;
 }
 
-void sieve_ast_argument_number_set
-(struct sieve_ast_argument *argument, unsigned int newnum)
+void sieve_ast_argument_number_set(struct sieve_ast_argument *argument,
+				   sieve_number_t newnum)
 {
-	i_assert( argument->type == SAAT_NUMBER );
+	i_assert(argument->type == SAAT_NUMBER);
 	argument->_value.number = newnum;
 }
 
-
-struct sieve_ast_argument *sieve_ast_arguments_detach
-(struct sieve_ast_argument *first, unsigned int count)
+struct sieve_ast_argument *
+sieve_ast_arguments_detach(struct sieve_ast_argument *first,
+			   unsigned int count)
 {
 	return sieve_ast_arg_list_detach(first, count);
 }
 
-bool sieve_ast_argument_attach
-(struct sieve_ast_node *node, struct sieve_ast_argument *argument)
+bool sieve_ast_argument_attach(struct sieve_ast_node *node,
+			       struct sieve_ast_argument *argument)
 {
 	return sieve_ast_node_add_argument(node, argument);
 }
 
-const char *sieve_ast_argument_type_name
-(enum sieve_ast_argument_type arg_type)
+const char *sieve_ast_argument_type_name(enum sieve_ast_argument_type arg_type)
 {
-	switch ( arg_type ) {
-
-	case SAAT_NONE: return "none";
-	case SAAT_STRING_LIST: return "a string list";
-	case SAAT_STRING: return "a string";
-	case SAAT_NUMBER: return "a number";
-	case SAAT_TAG: return "a tag";
-
-	default: return "??ARGUMENT??";
+	switch (arg_type) {
+	case SAAT_NONE:
+		return "none";
+	case SAAT_STRING_LIST:
+		return "a string list";
+	case SAAT_STRING:
+		return "a string";
+	case SAAT_NUMBER:
+		return "a number";
+	case SAAT_TAG:
+		return "a tag";
+	default:
+		return "??ARGUMENT??";
 	}
 }
 
 /* Test AST node */
 
-struct sieve_ast_node *sieve_ast_test_create
-(struct sieve_ast_node *parent, const char *identifier,
-	unsigned int source_line)
+struct sieve_ast_node *
+sieve_ast_test_create(struct sieve_ast_node *parent, const char *identifier,
+		      unsigned int source_line)
 {
-	struct sieve_ast_node *test = sieve_ast_node_create
-		(parent->ast, parent, SAT_TEST, source_line);
+	struct sieve_ast_node *test = sieve_ast_node_create(
+		parent->ast, parent, SAT_TEST, source_line);
 
 	test->identifier = p_strdup(parent->ast->pool, identifier);
 
-	if ( !sieve_ast_node_add_test(parent, test) )
+	if (!sieve_ast_node_add_test(parent, test))
 		return NULL;
-
 	return test;
 }
 
 /* Command AST node */
 
-struct sieve_ast_node *sieve_ast_command_create
-(struct sieve_ast_node *parent, const char *identifier,
-	unsigned int source_line)
+struct sieve_ast_node *
+sieve_ast_command_create(struct sieve_ast_node *parent, const char *identifier,
+			 unsigned int source_line)
 {
-
-	struct sieve_ast_node *command = sieve_ast_node_create
-		(parent->ast, parent, SAT_COMMAND, source_line);
+	struct sieve_ast_node *command = sieve_ast_node_create(
+		parent->ast, parent, SAT_COMMAND, source_line);
 
 	command->identifier = p_strdup(parent->ast->pool, identifier);
 
-	if ( !sieve_ast_node_add_command(parent, command) )
+	if (!sieve_ast_node_add_command(parent, command))
 		return NULL;
-
 	return command;
 }
 
@@ -777,22 +802,21 @@ struct sieve_ast_node *sieve_ast_command_create
  * Utility
  */
 
-int sieve_ast_stringlist_map
-(struct sieve_ast_argument **listitem, void *context,
+int sieve_ast_stringlist_map(
+	struct sieve_ast_argument **listitem, void *context,
 	int (*map_function)(void *context, struct sieve_ast_argument *arg))
 {
-	if ( sieve_ast_argument_type(*listitem) == SAAT_STRING ) {
+	if (sieve_ast_argument_type(*listitem) == SAAT_STRING) {
 		/* Single string */
 		return map_function(context, *listitem);
-	} else if ( sieve_ast_argument_type(*listitem) == SAAT_STRING_LIST ) {
+	} else if (sieve_ast_argument_type(*listitem) == SAAT_STRING_LIST) {
 		int ret = 0;
 
 		/* String list */
 		*listitem = sieve_ast_strlist_first(*listitem);
 
-		while ( *listitem != NULL ) {
-
-			if ( (ret=map_function(context, *listitem)) <= 0 )
+		while (*listitem != NULL) {
+			if ((ret = map_function(context, *listitem)) <= 0)
 				return ret;
 
 			*listitem = sieve_ast_strlist_next(*listitem);
@@ -805,8 +829,9 @@ int sieve_ast_stringlist_map
 	return -1;
 }
 
-struct sieve_ast_argument *sieve_ast_stringlist_join
-(struct sieve_ast_argument *list, struct sieve_ast_argument *items)
+struct sieve_ast_argument *
+sieve_ast_stringlist_join(struct sieve_ast_argument *list,
+			  struct sieve_ast_argument *items)
 {
 	enum sieve_ast_argument_type list_type, items_type;
 	struct sieve_ast_argument *newlist;
@@ -814,92 +839,78 @@ struct sieve_ast_argument *sieve_ast_stringlist_join
 	list_type = sieve_ast_argument_type(list);
 	items_type = sieve_ast_argument_type(items);
 
-	switch ( list_type ) {
-
+	switch (list_type) {
 	case SAAT_STRING:
-		switch ( items_type ) {
-
+		switch (items_type) {
 		case SAAT_STRING:
-			newlist =
-				sieve_ast_argument_create(list->ast, list->source_line);
+			newlist = sieve_ast_argument_create(
+				list->ast, list->source_line);
 			newlist->type = SAAT_STRING_LIST;
 			newlist->_value.strlist = NULL;
 
 			sieve_ast_argument_substitute(list, newlist);
 			sieve_ast_arguments_detach(items, 1);
 
-			if ( !_sieve_ast_stringlist_add_item(newlist, list) ||
-				!_sieve_ast_stringlist_add_item(newlist, items) ) {
+			if (!_sieve_ast_stringlist_add_item(newlist, list) ||
+			    !_sieve_ast_stringlist_add_item(newlist, items))
 				return NULL;
-			}
-
 			return newlist;
-
 		case SAAT_STRING_LIST:
-			/* Adding stringlist to string; make them swith places and add one to the
-			 * other.
+			/* Adding stringlist to string; make them swith places
+			   and add one to the other.
 			 */
 			sieve_ast_arguments_detach(items, 1);
 			sieve_ast_argument_substitute(list, items);
-			if ( !_sieve_ast_stringlist_add_item(items, list) )
+			if (!_sieve_ast_stringlist_add_item(items, list))
 				return NULL;
-
 			return list;
-
 		default:
 			i_unreached();
 		}
 		break;
-
 	case SAAT_STRING_LIST:
-		switch ( items_type ) {
-
+		switch (items_type) {
 		case SAAT_STRING:
 			/* Adding string to stringlist; straightforward add */
 			sieve_ast_arguments_detach(items, 1);
-			if ( !_sieve_ast_stringlist_add_item(list, items) )
+			if (!_sieve_ast_stringlist_add_item(list, items))
 				return NULL;
-
 			return list;
-
 		case SAAT_STRING_LIST:
-			/* Adding stringlist to stringlist; perform actual join */
+			/* Adding stringlist to stringlist; perform actual join
+			 */
 			sieve_ast_arguments_detach(items, 1);
-			if ( !sieve_ast_stringlist_add_stringlist(list, items) )
+			if (!sieve_ast_stringlist_add_stringlist(list, items))
 				return NULL;
-
 			return list;
-
 		default:
 			i_unreached();
 		}
-
 		break;
 	default:
 		i_unreached();
 	}
-
 	return NULL;
 }
 
-
 /* Debug */
 
 /* Unparsing, currently implemented using plain printf()s */
 
 static void sieve_ast_unparse_string(const string_t *strval)
 {
-	char *str = t_strdup_noconst(str_c((string_t *) strval));
+	char *str = t_strdup_noconst(str_c((string_t *)strval));
 
-	if ( strchr(str, '\n') != NULL && str[strlen(str)-1] == '\n' ) {
-		/* Print it as a multi-line string and do required dotstuffing */
+	if (strchr(str, '\n') != NULL && str[strlen(str)-1] == '\n') {
+		/* Print it as a multi-line string and do required dotstuffing
+		 */
 		char *spos = str;
 		char *epos = strchr(str, '\n');
 		printf("text:\n");
 
-		while ( epos != NULL ) {
+		while (epos != NULL) {
 			*epos = '\0';
-			if ( *spos == '.' )
+			if (*spos == '.')
 				printf(".");
 
 			printf("%s\n", spos);
@@ -907,8 +918,8 @@ static void sieve_ast_unparse_string(const string_t *strval)
 			spos = epos+1;
 			epos = strchr(spos, '\n');
 		}
-		if ( *spos == '.' )
-				printf(".");
+		if (*spos == '.')
+			printf(".");
 
 		printf("%s\n.\n", spos);
 	} else {
@@ -917,7 +928,7 @@ static void sieve_ast_unparse_string(const string_t *strval)
 		char *epos = strchr(str, '"');
 		printf("\"");
 
-		while ( epos != NULL ) {
+		while (epos != NULL) {
 			*epos = '\0';
 			printf("%s\\\"", spos);
 
@@ -929,33 +940,35 @@ static void sieve_ast_unparse_string(const string_t *strval)
 	}
 }
 
-static void sieve_ast_unparse_argument
-	(struct sieve_ast_argument *argument, int level);
+static void
+sieve_ast_unparse_argument(struct sieve_ast_argument *argument, int level);
 
-static void sieve_ast_unparse_stringlist
-(struct sieve_ast_argument *strlist, int level)
+static void
+sieve_ast_unparse_stringlist(struct sieve_ast_argument *strlist, int level)
 {
 	struct sieve_ast_argument *stritem;
 
-	if ( sieve_ast_strlist_count(strlist) > 1 ) {
+	if (sieve_ast_strlist_count(strlist) > 1) {
 		int i;
 
 		printf("[\n");
 
 		/* Create indent */
-		for ( i = 0; i < level+2; i++ )
+		for (i = 0; i < level+2; i++)
 			printf("  ");
 
 		stritem = sieve_ast_strlist_first(strlist);
-		if ( stritem != NULL ) {
-			sieve_ast_unparse_string(sieve_ast_strlist_str(stritem));
+		if (stritem != NULL) {
+			sieve_ast_unparse_string(
+				sieve_ast_strlist_str(stritem));
 
 			stritem = sieve_ast_strlist_next(stritem);
-			while ( stritem != NULL ) {
+			while (stritem != NULL) {
 				printf(",\n");
-				for ( i = 0; i < level+2; i++ )
+				for (i = 0; i < level+2; i++)
 					printf("  ");
-				sieve_ast_unparse_string(sieve_ast_strlist_str(stritem));
+				sieve_ast_unparse_string(
+					sieve_ast_strlist_str(stritem));
 				stritem = sieve_ast_strlist_next(stritem);
 			}
 		}
@@ -963,15 +976,17 @@ static void sieve_ast_unparse_stringlist
 		printf(" ]");
 	} else {
 		stritem = sieve_ast_strlist_first(strlist);
-		if ( stritem != NULL )
-			sieve_ast_unparse_string(sieve_ast_strlist_str(stritem));
+		if (stritem != NULL) {
+			sieve_ast_unparse_string(
+				sieve_ast_strlist_str(stritem));
+		}
 	}
 }
 
-static void sieve_ast_unparse_argument
-(struct sieve_ast_argument *argument, int level)
+static void
+sieve_ast_unparse_argument(struct sieve_ast_argument *argument, int level)
 {
-	switch ( argument->type ) {
+	switch (argument->type) {
 	case SAAT_STRING:
 		sieve_ast_unparse_string(sieve_ast_argument_str(argument));
 		break;
@@ -979,7 +994,8 @@ static void sieve_ast_unparse_argument
 		sieve_ast_unparse_stringlist(argument, level+1);
 		break;
 	case SAAT_NUMBER:
-		printf("%d", sieve_ast_argument_number(argument));
+		printf("%"SIEVE_PRI_NUMBER,
+		       sieve_ast_argument_number(argument));
 		break;
 	case SAAT_TAG:
 		printf(":%s", sieve_ast_argument_tag(argument));
@@ -990,52 +1006,49 @@ static void sieve_ast_unparse_argument
 	}
 }
 
-static void sieve_ast_unparse_test
-	(struct sieve_ast_node *node, int level);
+static void sieve_ast_unparse_test(struct sieve_ast_node *node, int level);
 
-static void sieve_ast_unparse_tests
-(struct sieve_ast_node *node, int level)
+static void sieve_ast_unparse_tests(struct sieve_ast_node *node, int level)
 {
 	struct sieve_ast_node *test;
 
-	if ( sieve_ast_test_count(node) > 1 ) {
+	if (sieve_ast_test_count(node) > 1) {
 		int i;
 
 		printf(" (\n");
 
 		/* Create indent */
-		for ( i = 0; i < level+2; i++ )
+		for (i = 0; i < level+2; i++)
 			printf("  ");
 
 		test = sieve_ast_test_first(node);
 		sieve_ast_unparse_test(test, level+1);
 
 		test = sieve_ast_test_next(test);
-		while ( test != NULL ) {
+		while (test != NULL) {
 			printf(", \n");
-			for ( i = 0; i < level+2; i++ )
+			for (i = 0; i < level+2; i++)
 				printf("  ");
 			sieve_ast_unparse_test(test, level+1);
-		  test = sieve_ast_test_next(test);
-	  }
+			test = sieve_ast_test_next(test);
+		}
 
 		printf(" )");
 	} else {
 		test = sieve_ast_test_first(node);
-		if ( test != NULL )
+		if (test != NULL)
 			sieve_ast_unparse_test(test, level);
 	}
 }
 
-static void sieve_ast_unparse_test
-(struct sieve_ast_node *node, int level)
+static void sieve_ast_unparse_test(struct sieve_ast_node *node, int level)
 {
 	struct sieve_ast_argument *argument;
 
 	printf(" %s", node->identifier);
 
 	argument = sieve_ast_argument_first(node);
-	while ( argument != NULL ) {
+	while (argument != NULL) {
 		printf(" ");
 		sieve_ast_unparse_argument(argument, level);
 		argument = sieve_ast_argument_next(argument);
@@ -1044,8 +1057,7 @@ static void sieve_ast_unparse_test
 	sieve_ast_unparse_tests(node, level);
 }
 
-static void sieve_ast_unparse_command
-(struct sieve_ast_node *node, int level)
+static void sieve_ast_unparse_command(struct sieve_ast_node *node, int level)
 {
 	struct sieve_ast_node *command;
 	struct sieve_ast_argument *argument;
@@ -1053,13 +1065,13 @@ static void sieve_ast_unparse_command
 	int i;
 
 	/* Create indent */
-	for ( i = 0; i < level; i++ )
+	for (i = 0; i < level; i++)
 		printf("  ");
 
 	printf("%s", node->identifier);
 
 	argument = sieve_ast_argument_first(node);
-	while ( argument != NULL ) {
+	while (argument != NULL) {
 		printf(" ");
 		sieve_ast_unparse_argument(argument, level);
 		argument = sieve_ast_argument_next(argument);
@@ -1068,15 +1080,15 @@ static void sieve_ast_unparse_command
 	sieve_ast_unparse_tests(node, level);
 
 	command = sieve_ast_command_first(node);
-	if ( command != NULL ) {
+	if (command != NULL) {
 		printf(" {\n");
 
-		while ( command != NULL) {
+		while (command != NULL) {
 			sieve_ast_unparse_command(command, level+1);
 			command = sieve_ast_command_next(command);
 		}
 
-		for ( i = 0; i < level; i++ )
+		for (i = 0; i < level; i++)
 			printf("  ");
 		printf("}\n");
 	} else
@@ -1091,11 +1103,9 @@ void sieve_ast_unparse(struct sieve_ast *ast)
 
 	T_BEGIN {
 		command = sieve_ast_command_first(sieve_ast_root(ast));
-		while ( command != NULL ) {
+		while (command != NULL) {
 			sieve_ast_unparse_command(command, 0);
 			command = sieve_ast_command_next(command);
 		}
 	} T_END;
 }
-
-
